from datetime import datetime, timedelta

import pytest

pytestmark = pytest.mark.django_db


def url(include_virtual=False):
    if include_virtual:
        return "/api/v1/playout/?include_virtual=true"

    return "/api/v1/playout/"


def create_daily_schedule(admin_api_client, daily_rrule, show) -> None:
    """creates a schedule for a show that repeats daily using the REST API."""

    now = datetime.now()
    in_one_hour = now + timedelta(hours=1)
    in_seven_days = now + timedelta(days=7)

    data = {
        "schedule": {
            "end_time": in_one_hour.strftime("%H:%M:%S"),
            "first_date": now.strftime("%Y-%m-%d"),
            "last_date": in_seven_days.strftime("%Y-%m-%d"),
            "rrule_id": daily_rrule.id,
            "show_id": show.id,
            "start_time": now.strftime("%H:%M:%S"),
        }
    }

    admin_api_client.post("/api/v1/schedules/", data=data, format="json")


def test_playout(admin_api_client, api_client, daily_rrule, show):
    create_daily_schedule(admin_api_client, daily_rrule, show)

    response = api_client.get(url())

    assert response.status_code == 200
    assert len(response.json()) == 7

    for entry in response.json():
        assert not entry["isVirtual"]
        assert entry["showId"] == show.id
        assert entry["showName"] == show.name


def test_playout_include_virtual(
    admin_api_client,
    api_client,
    daily_rrule,
    show,
    fallback_show,
    radio_settings,
):
    create_daily_schedule(admin_api_client, daily_rrule, show)

    response = api_client.get(url(include_virtual=True))

    assert response.status_code == 200
    assert len(response.json()) == 14 or 15

    for entry in response.json():
        if entry["isVirtual"]:
            assert entry["showId"] == fallback_show.id
            assert entry["showName"] == fallback_show.name
        else:
            assert entry["showId"] == show.id
            assert entry["showName"] == show.name
